@@ -89,6 +89,21 @@ class TableauWorksheet:
                         else:
                             del self._scraper.filters[worksheet][foundFilterIndex]
                             self._scraper.filters[worksheet].append(newFilter)
+        # persist zones
+        if ("applicationPresModel" in cmdResponse["vqlCmdResponse"]["layoutStatus"]):
+            presModel = cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
+            newZones = utils.getZones(presModel)
+            newZonesStorage = {}
+            for zone in newZones.keys():
+                zoneHasVizdata = utils.hasVizData(newZones[zone])
+                if (not zoneHasVizdata) and (zone in self._scraper.zones):
+                    newZonesStorage[zone] = copy.deepcopy(
+                        self._scraper.zones[zone])
+                else:
+                    newZonesStorage[zone] = copy.deepcopy(newZones[zone])
+            self._scraper.zones = newZonesStorage
+        else:
+            self._scraper.zones = {}
 
     def getColumns(self) -> List[str]:
         if self.cmdResponse:
@@ -145,12 +160,11 @@ class TableauWorksheet:
 
             # get selection from filterJson
             if (len(filter[0]["selection"]) > 0):
-                for idx, val in enumerate(filter[0]["values"]):
-                    if val in filter[0]["selection"]:
+                for idx, val in enumerate(filter[0]["selection"]):
+                    if val != value:
                         selectedIndex.append(idx)
-
             # get selection from quickFilter
-            if (len(filter[0]["selectionAlt"]) > 0) and ("domainTables" in filter[0]["selectionAlt"][0]):
+            elif (len(filter[0]["selectionAlt"]) > 0) and ("domainTables" in filter[0]["selectionAlt"][0]):
                 for idx, val in enumerate(filter[0]["selectionAlt"][0]["domainTables"]):
                     if ("isSelected" in val) and val["isSelected"] and (idx not in selectedIndex):
                         selectedIndex.append(idx)
